# -*- coding: utf8 -*-

import sys
from jinja2 import nodes
from jinja2.ext import Extension, Markup

from pygments import highlight
from pygments.lexers import get_lexer_by_name, guess_lexer
from pygments.formatters import HtmlFormatter
from pygments.util import ClassNotFound

class HighlightExtension(Extension):
    """Highlight code blocks using Pygments

    Example::

        {% highlight 'python' %}

        from fridge import Beer

        pint_glass = Beer()
        pint_glass.drink()

        {% endhighlight %}
    """
    tags = set(['highlight'])

    def parse(self, parser):
        lineno = next(parser.stream).lineno

        # TODO:
        # add support to show line numbers

        # extract the language if available
        if not parser.stream.current.test('block_end'):
            lang = parser.parse_expression()
        else:
            lang = nodes.Const(None)

        # body of the block
        body = parser.parse_statements(['name:endhighlight'], drop_needle=True)

        return nodes.CallBlock(self.call_method('_highlight', [lang]),
                               [], [], body).set_lineno(lineno)

    def _highlight(self, lang, caller=None):
        # highlight code using Pygments
        body = caller()
        try:
            if lang is None:
                lexer = guess_lexer(body)
            else:
                lexer = get_lexer_by_name(lang, stripall=False)
        except ClassNotFound as e:
            print(e)
            sys.exit(1)

        formatter = HtmlFormatter()
        code = highlight(Markup(body).unescape(), lexer, formatter)
        return code




from setuptools import setup

setup (
    name='jinja2-highlight',
    version='0.5.1',
    description='Jinja2 extension to highlight source code using Pygments',
    keywords = 'syntax highlighting',
    author='Tasos Latsas',
    author_email='tlatsas2000@gmail.com',
    url='https://github.com/tlatsas/jinja2-highlight',
    license='GNU GPLv3',
    packages=['jinja2_highlight'],
    install_requires=[
        'Jinja2>=2.4',
        'Pygments>=1.5'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Markup :: HTML'
    ],
)
